#
# spec file for package dnf5
#
# Copyright (c) 2023 Red Hat, Inc.
# Copyright (c) 2024 Neal Gompa.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# ========== build options ==========

%bcond_with    as_microdnf
%bcond_with    as_dnf
%bcond_with    as_yum

%bcond_without dnf5daemon_client
%bcond_without dnf5daemon_server
%bcond_without libdnf_cli
%bcond_without dnf5
%bcond_without dnf5_plugins
%bcond_without plugin_actions
%bcond_without python_plugins_loader

%bcond_without comps
%bcond_without modulemd
%bcond_without zchunk

%bcond_with    html
%bcond_without man

# openSUSE requires this
%bcond_without static_libsolv

# TODO Go bindings fail to build, disable for now
%bcond_with    go
%bcond_without perl5
%bcond_without python3
%bcond_without ruby

# Tests are currently broken: https://github.com/rpm-software-management/dnf5/issues/1893
%bcond_with    tests
%bcond_with    sanitizers
%bcond_with    performance_tests
%bcond_with    dnf5daemon_tests

# ========== versions of dependencies ==========

%global libmodulemd_version 2.5.0
%global librepo_version 1.18.0
%global libsolv_version 0.7.30
%global sqlite_version 3.35.0
%global swig_version 4
%global zchunk_version 0.9.11
%global libcurl_version 7.62.0

# ====== versioned library package names ======

%global libprefix libdnf5
%global libcliprefix libdnf5-cli
%global libsoversion 2
%global libclisoversion 2

%global libname %{libprefix}_%{libsoversion}
%global libcliname %{libcliprefix}%{libclisoversion}
%global devname %{libprefix}-devel
%global devcliname %{libcliprefix}-devel

Name:           dnf5
Version:        5.2.8.1
Release:        1.2
Summary:        Next generation RPM package manager
License:        GPL-2.0-or-later
URL:            https://github.com/rpm-software-management/dnf5
Source0:        %{url}/archive/%{version}/dnf5-%{version}.tar.gz

# Backports from upstream

# Proposed upstream
## Fix with sdbus-cpp v2
Patch0101:      https://github.com/rpm-software-management/dnf5/pull/1888.patch#/dnf5-PR1888.patch

# openSUSE specific fixes
## Fix libdnf build with static libsolvext
Patch1001:      dnf5-with-static-libsolvext.patch
## Migrate DNF persistent state directory to /usr/lib/sysimage
Patch1002:      dnf5-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
## Switch default reposdir to /etc/dnf/repos.d
Patch1003:      dnf5-Switch-default-reposdir-to-etc-dnf-repos.d.patch
## Disable Werror to fix bindings builds
Patch1004:      dnf5-disable-Werror.patch

Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}
Requires:       dnf-data
Recommends:     bash-completion

%if %{with as_microdnf}
# We want to replace Micro DNF
Obsoletes:      microdnf < 4
Provides:       microdnf = %{version}-%{release}
%endif

%if %{with as_dnf}
# We want to replace DNF
Obsoletes:      dnf < 5
Provides:       dnf = %{version}-%{release}
%endif

%if %{with as_yum}
# We want to replace YUM
Obsoletes:      yum < 5
Provides:       yum = %{version}-%{release}
%endif

Provides:       dnf5-command(advisory)
Provides:       dnf5-command(autoremove)
Provides:       dnf5-command(check)
Provides:       dnf5-command(check-upgrade)
Provides:       dnf5-command(clean)
Provides:       dnf5-command(distro-sync)
Provides:       dnf5-command(downgrade)
Provides:       dnf5-command(download)
Provides:       dnf5-command(environment)
Provides:       dnf5-command(group)
Provides:       dnf5-command(history)
Provides:       dnf5-command(info)
Provides:       dnf5-command(install)
Provides:       dnf5-command(leaves)
Provides:       dnf5-command(list)
Provides:       dnf5-command(makecache)
Provides:       dnf5-command(mark)
Provides:       dnf5-command(module)
Provides:       dnf5-command(offline)
Provides:       dnf5-command(provides)
Provides:       dnf5-command(reinstall)
Provides:       dnf5-command(remove)
Provides:       dnf5-command(repo)
Provides:       dnf5-command(repoquery)
Provides:       dnf5-command(search)
Provides:       dnf5-command(swap)
Provides:       dnf5-command(system-upgrade)
Provides:       dnf5-command(upgrade)
Provides:       dnf5-command(versionlock)

# ========== build requires ==========

BuildRequires:  bash-completion-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  git-core
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
BuildRequires:  pkgconfig(libsolv) >= %{libsolv_version}
BuildRequires:  pkgconfig(libsolvext) >= %{libsolv_version}
BuildRequires:  pkgconfig(rpm) >= 4.17.0
BuildRequires:  pkgconfig(sqlite3) >= %{sqlite_version}
BuildRequires:  pkgconfig(systemd)
BuildRequires:  toml11-devel

%if %{with tests}
BuildRequires:  createrepo_c
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  rpm-build
%endif

%if %{with comps}
BuildRequires:  pkgconfig(libcomps)
%endif

%if %{with modulemd}
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
%endif

%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= %{zchunk_version}
%endif

%if %{with static_libsolv}
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libzstd)
%endif

%if %{with html} || %{with man}
#BuildRequires:  python3dist(breathe)
BuildRequires:  python3-breathe
#BuildRequires:  python3dist(sphinx) >= 4.1.2
BuildRequires:  python3-Sphinx >= 4.1.2
#BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3-sphinx_rtd_theme
# requests requires ca-certs to work properly
BuildRequires:  ca-certificates-mozilla
%endif

%if %{with sanitizers}
BuildRequires:  libasan
BuildRequires:  liblsan
BuildRequires:  libubsan
%endif

%if %{with libdnf_cli}
# required for libdnf5-cli
BuildRequires:  pkgconfig(smartcols)
%endif

%if %{with dnf5_plugins}
# required for config-manager
BuildRequires:  libcurl-devel >= %{libcurl_version}
%endif

%if %{with dnf5daemon_server}
# required for dnf5daemon-server
BuildRequires:  pkgconfig(sdbus-c++) >= 0.9.0
BuildRequires:  systemd-rpm-macros
%if %{with dnf5daemon_tests}
BuildRequires:  dbus-1-daemon
BuildRequires:  polkit
BuildRequires:  python3-devel
#BuildRequires:  python3dist(dbus-python)
BuildRequires:  python3-dbus-python
%endif
%endif

# ========== language bindings section ==========

%if %{with perl5} || %{with ruby} || %{with python3}
BuildRequires:  swig >= %{swig_version}
%endif

%if %{with perl5}
# required for perl-libdnf5 and perl-libdnf5-cli
BuildRequires:  perl
%if %{with tests}
BuildRequires:  perl(strict)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(warnings)
BuildRequires:  perl(FindBin)
%endif
%endif

%if %{with ruby}
# required for ruby-libdnf5 and ruby-libdnf5-cli
BuildRequires:  ruby-devel
BuildRequires:  ruby-macros
%if %{with tests}
BuildRequires:  rubygem(test-unit)
%endif
%endif

%if %{with python3}
# required for python3-libdnf5 and python3-libdnf5-cli
BuildRequires:  python3-devel
%endif

%description
DNF5 is a command-line package manager that automates the process of installing,
upgrading, configuring, and removing computer programs in a consistent manner.
It supports RPM packages, modulemd modules, and comps groups & environments.

%post
%systemd_post dnf5-makecache.timer

%preun
%systemd_preun dnf5-makecache.timer

%postun
%systemd_postun_with_restart dnf5-makecache.timer


%files -f dnf5.lang
%{_bindir}/dnf5
%if %{with as_microdnf}
%{_bindir}/microdnf
%endif
%if %{with as_dnf}
%{_bindir}/dnf
%{_mandir}/man?/dnf-*
%endif
%if %{with as_yum}
%{_bindir}/yum
%endif

%{_unitdir}/dnf5-makecache.service
%{_unitdir}/dnf5-makecache.timer

%dir %{_sysconfdir}/dnf
%dir %{_sysconfdir}/dnf/dnf5-aliases.d
%doc %{_sysconfdir}/dnf/dnf5-aliases.d/README
%dir %{_sysconfdir}/dnf/dnf5-plugins
%dir %{_datadir}/dnf5
%dir %{_datadir}/dnf5/aliases.d
%config %{_datadir}/dnf5/aliases.d/compatibility.conf
%dir %{_datadir}/dnf5/dnf5-plugins
%dir %{_libdir}/dnf5
%dir %{_libdir}/dnf5/plugins
%doc %{_libdir}/dnf5/plugins/README
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/dnf5
%if %{with as_dnf}
%{_datadir}/bash-completion/completions/dnf
%endif
%dir %{_prefix}/lib/sysimage/dnf
%verify(not md5 size mtime) %ghost %{_prefix}/lib/sysimage/dnf/*
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/dnf5.8.*
%{_mandir}/man8/dnf5-advisory.8.*
%{_mandir}/man8/dnf5-autoremove.8.*
%{_mandir}/man8/dnf5-check.8.*
%{_mandir}/man8/dnf5-check-upgrade.8.*
%{_mandir}/man8/dnf5-clean.8.*
%{_mandir}/man8/dnf5-distro-sync.8.*
%{_mandir}/man8/dnf5-downgrade.8.*
%{_mandir}/man8/dnf5-download.8.*
%{_mandir}/man8/dnf5-environment.8.*
%{_mandir}/man8/dnf5-group.8.*
%{_mandir}/man8/dnf5-history.8.*
%{_mandir}/man8/dnf5-info.8.*
%{_mandir}/man8/dnf5-install.8.*
%{_mandir}/man8/dnf5-leaves.8.*
%{_mandir}/man8/dnf5-list.8.*
%{_mandir}/man8/dnf5-makecache.8.*
%{_mandir}/man8/dnf5-mark.8.*
%{_mandir}/man8/dnf5-module.8.*
%{_mandir}/man8/dnf5-offline.8.*
%{_mandir}/man8/dnf5-provides.8.*
%{_mandir}/man8/dnf5-reinstall.8.*
%{_mandir}/man8/dnf5-remove.8.*
%{_mandir}/man8/dnf5-replay.8.*
%{_mandir}/man8/dnf5-repo.8.*
%{_mandir}/man8/dnf5-repoquery.8.*
%{_mandir}/man8/dnf5-search.8.*
%{_mandir}/man8/dnf5-swap.8.*
%{_mandir}/man8/dnf5-system-upgrade.8.*
%{_mandir}/man8/dnf5-upgrade.8.*
%{_mandir}/man8/dnf5-versionlock.8.*
%{_mandir}/man7/dnf5-aliases.7.*
%{_mandir}/man7/dnf5-caching.7.*
%{_mandir}/man7/dnf5-changes-from-dnf4.7.*
%{_mandir}/man7/dnf5-comps.7.*
%{_mandir}/man7/dnf5-filtering.7.*
%{_mandir}/man7/dnf5-forcearch.7.*
%{_mandir}/man7/dnf5-installroot.7.*
%{_mandir}/man7/dnf5-modularity.7.*
%{_mandir}/man7/dnf5-specs.7.*
%{_mandir}/man7/dnf5-system-state.7.*
%{_mandir}/man5/dnf5.conf.5.*
%{_mandir}/man5/dnf5.conf-todo.5.*
%{_mandir}/man5/dnf5.conf-deprecated.5.*

%{_unitdir}/dnf5-offline-transaction.service
%{_unitdir}/dnf5-offline-transaction-cleanup.service
%dir %{_unitdir}/system-update.target.wants
%{_unitdir}/system-update.target.wants/dnf5-offline-transaction.service

# ========== libdnf5 ==========
%package -n %{libname}
Summary:        Package management library
License:        LGPL-2.1-or-later
Requires:       libmodulemd2%{?_isa} >= %{libmodulemd_version}
#Requires:       libsolv%{?_isa} >= %{libsolv_version}
Requires:       librepo0%{?_isa} >= %{librepo_version}
Requires:       libsqlite3-0%{?_isa} >= %{sqlite_version}

%description -n %{libname}
Package management library.

%ldconfig_scriptlets -n %{libname}

%files -n %{libname} -f libdnf5.lang
%dir %{_libdir}/libdnf5
%{_libdir}/libdnf5.so.%{libsoversion}
%license lgpl-2.1.txt
%ghost %attr(0755, root, root) %dir %{_var}/cache/libdnf5
%dir %{_datadir}/dnf5/libdnf.conf.d
%dir %{_sysconfdir}/dnf/libdnf5.conf.d
%dir %{_datadir}/dnf5/repos.override.d
%dir %{_sysconfdir}/dnf/repos.override.d
%dir %{_sysconfdir}/dnf/libdnf5-plugins
%dir %{_libdir}/libdnf5/plugins
%dir %{_datadir}/dnf5/repos.d
%dir %{_datadir}/dnf5/vars.d

# ========== libdnf5-cli ==========

%if %{with libdnf_cli}
%package -n %{libcliname}
Summary:        Library for working with a terminal in a command-line package manager
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{libcliname}
Library for working with a terminal in a command-line package manager.

%ldconfig_scriptlets -n %{libcliname}

%files -n %{libcliname} -f libdnf5-cli.lang
%{_libdir}/libdnf5-cli.so.%{libclisoversion}
%license COPYING.md
%license lgpl-2.1.txt
%endif

# ========== dnf5-devel ==========

%package -n dnf5-devel
Summary:        Development files for dnf5
License:        LGPL-2.1-or-later
Requires:       dnf5%{?_isa} = %{version}-%{release}
Requires:       %{devname}%{?_isa} = %{version}-%{release}
Requires:       %{devcliname}%{?_isa} = %{version}-%{release}

%description -n dnf5-devel
Develpment files for dnf5.

%files -n dnf5-devel
%{_includedir}/dnf5/
%license COPYING.md
%license lgpl-2.1.txt


# ========== libdnf5-devel ==========

%package -n %{devname}
Summary:        Development files for libdnf
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       libsolv-devel%{?_isa} >= %{libsolv_version}
# Do not conflict with libdnf-devel yet, packagekit needs both devel packages for now.
#Conflicts:      libdnf-devel < 5

%description -n %{devname}
Development files for libdnf.

%files -n %{devname}
%{_includedir}/libdnf5/
%dir %{_libdir}/libdnf5
%{_libdir}/libdnf5.so
%{_libdir}/pkgconfig/libdnf5.pc
%license COPYING.md
%license lgpl-2.1.txt


# ========== libdnf5-cli-devel ==========

%package -n %{devcliname}
Summary:        Development files for libdnf5-cli
License:        LGPL-2.1-or-later
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}

%description -n %{devcliname}
Development files for libdnf5-cli.

%files -n %{devcliname}
%{_includedir}/libdnf5-cli/
%{_libdir}/libdnf5-cli.so
%{_libdir}/pkgconfig/libdnf5-cli.pc
%license COPYING.md
%license lgpl-2.1.txt


# ========== perl-libdnf5 ==========

%if %{with perl5}
%package -n perl-libdnf5
Summary:        Perl 5 bindings for the libdnf library
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}


%description -n perl-libdnf5
Perl 5 bindings for the libdnf library.

%files -n perl-libdnf5
%{perl_vendorarch}/libdnf5
%{perl_vendorarch}/auto/libdnf5
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== perl-libdnf5-cli ==========

%if %{with perl5} && %{with libdnf_cli}
%package -n perl-libdnf5-cli
Summary:        Perl 5 bindings for the libdnf5-cli library
License:        LGPL-2.1-or-later
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}


%description -n perl-libdnf5-cli
Perl 5 bindings for the libdnf5-cli library.

%files -n perl-libdnf5-cli
%{perl_vendorarch}/libdnf5_cli
%{perl_vendorarch}/auto/libdnf5_cli
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== python3-libdnf5 ==========

%if %{with python3}
%package -n python3-libdnf5
%{?python_provide:%python_provide python3-libdnf}
Summary:        Python 3 bindings for the libdnf library
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n python3-libdnf5
Python 3 bindings for the libdnf library.

%files -n python3-libdnf5
%{python3_sitearch}/libdnf5
%{python3_sitearch}/libdnf5-*.dist-info
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== python3-libdnf5-cli ==========

%if %{with python3} && %{with libdnf_cli}
%package -n python3-libdnf5-cli
%{?python_provide:%python_provide python3-libdnf5-cli}
Summary:        Python 3 bindings for the libdnf5-cli library
License:        LGPL-2.1-or-later
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}

%description -n python3-libdnf5-cli
Python 3 bindings for the libdnf5-cli library.

%files -n python3-libdnf5-cli
%{python3_sitearch}/libdnf5_cli
%{python3_sitearch}/libdnf5_cli-*.dist-info
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== ruby-libdnf5 ==========

%if %{with ruby}
%package -n ruby-libdnf5
Summary:        Ruby bindings for the libdnf library
License:        LGPL-2.1-or-later
Provides:       ruby(libdnf) = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n ruby-libdnf5
Ruby bindings for the libdnf library.

%files -n ruby-libdnf5
%{rb_vendorarchdir}/libdnf5
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== ruby-libdnf5-cli ==========

%if %{with ruby} && %{with libdnf_cli}
%package -n ruby-libdnf5-cli
Summary:        Ruby bindings for the libdnf5-cli library
License:        LGPL-2.1-or-later
Provides:       ruby(libdnf_cli) = %{version}-%{release}
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}

%description -n ruby-libdnf5-cli
Ruby bindings for the libdnf5-cli library.

%files -n ruby-libdnf5-cli
%{rb_vendorarchdir}/libdnf5_cli
%license COPYING.md
%license lgpl-2.1.txt
%endif


# ========== libdnf5-plugin-actions ==========

%if %{with plugin_actions}
%package -n libdnf5-plugin-actions
Summary:        Libdnf plugin that allows to run actions (external executables) on hooks
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n libdnf5-plugin-actions
Libdnf plugin that allows to run actions (external executables) on hooks.

%files -n libdnf5-plugin-actions -f libdnf5-plugin-actions.lang
%{_libdir}/libdnf5/plugins/actions.*
%config(noreplace) %{_sysconfdir}/dnf/libdnf5-plugins/actions.conf
%dir %{_sysconfdir}/dnf/libdnf5-plugins/actions.d
%{_mandir}/man8/libdnf5-actions.8.*
%endif


# ========== python3-libdnf5-plugins-loader ==========

%if %{with python_plugins_loader}
%package -n python3-libdnf5-python-plugins-loader
Summary:        Libdnf plugin that allows loading Python plugins
License:        LGPL-2.1-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       python3-libdnf5%{?_isa} = %{version}-%{release}

%description -n python3-libdnf5-python-plugins-loader
Libdnf plugin that allows loading Python plugins.

%files -n python3-libdnf5-python-plugins-loader
%{_libdir}/libdnf5/plugins/python_plugins_loader.*
%dir %{python3_sitelib}/libdnf_plugins/
%doc %{python3_sitelib}/libdnf_plugins/README
%endif


# ========== dnf5daemon-client ==========

%if %{with dnf5daemon_client}
%package -n dnf5daemon-client
Summary:        Command-line interface for dnf5daemon-server
License:        GPL-2.0-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}
Requires:       dnf5daemon-server

%description -n dnf5daemon-client
Command-line interface for dnf5daemon-server.

%files -n dnf5daemon-client -f dnf5daemon-client.lang
%{_bindir}/dnf5daemon-client
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/dnf5daemon-client.8.*
%endif


# ========== dnf5daemon-server ==========

%if %{with dnf5daemon_server}
%package -n dnf5daemon-server
Summary:        Package management service with a DBus interface
License:        GPL-2.0-or-later
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}
Requires:       dbus-1-common
Requires:       dnf-data
Requires:       polkit

%description -n dnf5daemon-server
Package management service with a DBus interface.

%post -n dnf5daemon-server
%systemd_post dnf5daemon-server.service

%preun -n dnf5daemon-server
%systemd_preun dnf5daemon-server.service

%postun -n dnf5daemon-server
%systemd_postun_with_restart dnf5daemon-server.service

%files -n dnf5daemon-server -f dnf5daemon-server.lang
%{_sbindir}/dnf5daemon-server
%{_unitdir}/dnf5daemon-server.service
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/system.d
%dir %{_datadir}/dbus-1/system-services
%dir %{_datadir}/dbus-1/interfaces
%{_datadir}/dbus-1/system.d/org.rpm.dnf.v0.conf
%{_datadir}/dbus-1/system-services/org.rpm.dnf.v0.service
%{_datadir}/dbus-1/interfaces/org.rpm.dnf.v0.*.xml
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.rpm.dnf.v0.policy
%license COPYING.md
%license gpl-2.0.txt
%{_mandir}/man8/dnf5daemon-server.8.*
%{_mandir}/man8/dnf5daemon-dbus-api.8.*
%endif


# ========== dnf5-plugins ==========

%if %{with dnf5_plugins}
%package -n dnf5-plugins
Summary:        Plugins for dnf5
License:        LGPL-2.1-or-later
Requires:       libcurl4%{?_isa} >= %{libcurl_version}
Requires:       dnf5%{?_isa} = %{version}-%{release}
Requires:       %{libcliname}%{?_isa} = %{version}-%{release}
Provides:       dnf5-command(builddep)
Provides:       dnf5-command(changelog)
Provides:       dnf5-command(config-manager)
Provides:       dnf5-command(copr)
Provides:       dnf5-command(needs-restarting)
Provides:       dnf5-command(repoclosure)
Provides:       dnf5-command(reposync)

%description -n dnf5-plugins
Core DNF5 plugins that enhance dnf5 with builddep, changelog,
config-manager, copr, repoclosure, and reposync commands.

%files -n dnf5-plugins -f dnf5-plugin-builddep.lang -f dnf5-plugin-changelog.lang -f dnf5-plugin-config-manager.lang -f dnf5-plugin-copr.lang -f dnf5-plugin-needs-restarting.lang -f dnf5-plugin-repoclosure.lang -f dnf5-plugin-reposync.lang
%{_libdir}/dnf5/plugins/builddep_cmd_plugin.so
%{_libdir}/dnf5/plugins/changelog_cmd_plugin.so
%{_libdir}/dnf5/plugins/config-manager_cmd_plugin.so
%{_libdir}/dnf5/plugins/copr_cmd_plugin.so
%{_libdir}/dnf5/plugins/needs_restarting_cmd_plugin.so
%{_libdir}/dnf5/plugins/repoclosure_cmd_plugin.so
%{_libdir}/dnf5/plugins/reposync_cmd_plugin.so
%{_mandir}/man8/dnf5-builddep.8.*
%{_mandir}/man8/dnf5-changelog.8.*
%{_mandir}/man8/dnf5-config-manager.8.*
%{_mandir}/man8/dnf5-copr.8.*
%{_mandir}/man8/dnf5-needs-restarting.8.*
%{_mandir}/man8/dnf5-repoclosure.8.*
%{_mandir}/man8/dnf5-reposync.8.*
%{_datadir}/dnf5/aliases.d/compatibility-plugins.conf
%{_datadir}/dnf5/aliases.d/compatibility-reposync.conf

# ========== dnf5-automatic plugin ==========

%package plugin-automatic
Summary:        Package manager - automated upgrades
License:        LGPL-2.1-or-later
Requires:       dnf5%{?_isa} = %{version}-%{release}
Requires:       libcurl4%{?_isa} >= %{libcurl_version}
Provides:       dnf5-command(automatic)
%if %{with as_dnf}
Provides:       dnf-automatic = %{version}-%{release}
Obsoletes:      dnf-automatic < 5
%else
Conflicts:      dnf-automatic < 5
%endif

%description plugin-automatic
Alternative command-line interface "dnf upgrade" suitable to be executed
automatically and regularly from systemd timers, cron jobs or similar.

%files plugin-automatic -f dnf5-plugin-automatic.lang
%ghost %{_sysconfdir}/motd.d/dnf5-automatic
%{_libdir}/dnf5/plugins/automatic_cmd_plugin.so
%{_datadir}/dnf5/dnf5-plugins/automatic.conf
%ghost %config(noreplace) %{_sysconfdir}/dnf/automatic.conf
%ghost %config(noreplace) %{_sysconfdir}/dnf/dnf5-plugins/automatic.conf
%{_mandir}/man8/dnf5-automatic.8.*
%{_unitdir}/dnf5-automatic.service
%{_unitdir}/dnf5-automatic.timer
%{_unitdir}/dnf-automatic.service
%{_unitdir}/dnf-automatic.timer
%if %{with as_dnf}
%{_bindir}/dnf-automatic
%endif

%endif


# ========== unpack, build, check & install ==========

%prep
%autosetup -S git_am -n dnf5-%{version}


%build
%cmake \
    -DPERL_INSTALLDIRS=vendor \
    \
    -DENABLE_SOLV_FOCUSNEW=ON \
    -DWITH_SYSTEMD=ON \
    -DWITH_DNF5DAEMON_CLIENT=%{?with_dnf5daemon_client:ON}%{!?with_dnf5daemon_client:OFF} \
    -DWITH_DNF5DAEMON_SERVER=%{?with_dnf5daemon_server:ON}%{!?with_dnf5daemon_server:OFF} \
    -DWITH_LIBDNF5_CLI=%{?with_libdnf_cli:ON}%{!?with_libdnf_cli:OFF} \
    -DWITH_DNF5=%{?with_dnf5:ON}%{!?with_dnf5:OFF} \
    -DWITH_PLUGIN_ACTIONS=%{?with_plugin_actions:ON}%{!?with_plugin_actions:OFF} \
    -DWITH_PYTHON_PLUGINS_LOADER=%{?with_python_plugins_loader:ON}%{!?with_python_plugins_loader:OFF} \
    \
    -DWITH_COMPS=%{?with_comps:ON}%{!?with_comps:OFF} \
    -DWITH_MODULEMD=%{?with_modulemd:ON}%{!?with_modulemd:OFF} \
    -DWITH_ZCHUNK=%{?with_zchunk:ON}%{!?with_zchunk:OFF} \
    \
    -DWITH_STATIC_LIBSOLV=%{?with_static_libsolv:ON}%{!?with_static_libsolv:OFF} \
    \
    -DWITH_HTML=%{?with_html:ON}%{!?with_html:OFF} \
    -DWITH_MAN=%{?with_man:ON}%{!?with_man:OFF} \
    \
    -DWITH_GO=%{?with_go:ON}%{!?with_go:OFF} \
    -DWITH_PERL5=%{?with_perl5:ON}%{!?with_perl5:OFF} \
    -DWITH_PYTHON3=%{?with_python3:ON}%{!?with_python3:OFF} \
    -DWITH_RUBY=%{?with_ruby:ON}%{!?with_ruby:OFF} \
    \
    -DWITH_SANITIZERS=%{?with_sanitizers:ON}%{!?with_sanitizers:OFF} \
    -DWITH_TESTS=%{?with_tests:ON}%{!?with_tests:OFF} \
    -DWITH_PERFORMANCE_TESTS=%{?with_performance_tests:ON}%{!?with_performance_tests:OFF} \
    -DWITH_DNF5DAEMON_TESTS=%{?with_dnf5daemon_tests:ON}%{!?with_dnf5daemon_tests:OFF}
%cmake_build
%if %{with man}
    %cmake_build doc-man
%endif


%check
%if %{with tests}
    %ctest
%endif


%install
%cmake_install

# own dirs and files that dnf5 creates on runtime
mkdir -p %{buildroot}%{_prefix}/lib/sysimage/dnf
for files in \
    groups.toml modules.toml nevras.toml packages.toml \
    system.toml transaction_history.sqlite \
    transaction_history.sqlite-shm \
    transaction_history.sqlite-wal userinstalled.toml
do
    touch %{buildroot}%{_prefix}/lib/sysimage/dnf/$files
done

# own the offline transaction target
mkdir -p %{buildroot}%{_unitdir}/system-update.target.wants/
pushd %{buildroot}%{_unitdir}/system-update.target.wants/
  ln -sr ../dnf5-offline-transaction.service
popd

%find_lang dnf5
%find_lang dnf5-plugin-automatic
%find_lang dnf5-plugin-builddep
%find_lang dnf5-plugin-changelog
%find_lang dnf5-plugin-config-manager
%find_lang dnf5-plugin-copr
%find_lang dnf5-plugin-needs-restarting
%find_lang dnf5-plugin-repoclosure
%find_lang dnf5-plugin-reposync
%find_lang dnf5daemon-client
%find_lang dnf5daemon-server
%find_lang libdnf5
%find_lang libdnf5-cli
%find_lang libdnf5-plugin-actions

# Let's not replace what dnf-data offers just yet..
rm %{buildroot}%{_sysconfdir}/dnf/dnf.conf

%if %{with as_microdnf}
ln -sr %{buildroot}%{_bindir}/dnf5 %{buildroot}%{_bindir}/microdnf
%endif
%if %{with as_dnf}
ln -sr %{buildroot}%{_bindir}/dnf5 %{buildroot}%{_bindir}/dnf
ln -sr %{buildroot}%{_datadir}/bash-completion/completions/dnf5 %{buildroot}%{_datadir}/bash-completion/completions/dnf
for file in %{buildroot}%{_mandir}/man[578]/dnf5[-.]*; do
    dir=$(dirname $file)
    filename=$(basename $file)
    ln -sr $file $dir/${filename/dnf5/dnf}
done
%else
rm %{buildroot}%{_bindir}/dnf-automatic
%endif
%if %{with as_yum}
ln -sr %{buildroot}%{_bindir}/dnf5 %{buildroot}%{_bindir}/yum
%endif


%changelog
* Sun Dec  8 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.2.8.1
  + 5.2.8.1 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.8.1
  + 5.2.8.0 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.8.0
- Add patch to fix build with sdbus-cpp v2
  + Patch: dnf5-PR1888.patch
- Temporarily disable running tests until crashes are fixed (gh#rpm-software-management/dnf5#1893)
* Sun Nov 24 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.2.7.0
  + 5.2.7.0 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.7.0
  + 5.2.6.2 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.6.2
  + 5.2.6.1 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.6.1
  + 5.2.6.0 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.6.0
  + 5.2.5.0 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.5.0
  + 5.2.4.0 changelog: https://github.com/rpm-software-management/dnf5/releases/tag/5.2.4.0
- Refresh patches
  + Patch: dnf5-disable-Werror.patch
  + Patch: dnf5-with-static-libsolvext.patch
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Do not conflict with libdnf-devel yet, PackageKit needs both
  devel packages for now.
* Sat Jun  8 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.2.3.0
  + Update translations from weblate
  + const: Shared constant defining RPM transaction lock file
  + main: Implement checking of privileges before executing commands
  + exception: Add new exception for user insufficient privileges
  + locker: Move to public API
  + distro-sync: Add downloadonly option
  + commands: Fix using store option
  + Enhance warning about RPMs that were not validate by RPM
  + Vars::substitute: fix use-out-of-scope leaks
  + docs: correct the default for pluginconfpath
  + cli: Add skipped packages to the transaction table
  + i18n: Improve formatting an error message for multiple streams
  + Add/fix documentation for rpm::PackageQuery methods
  + i18n: Unwind "No {} to remove for argument: {}"
  + `history list`: count also groups and envs in total `Altered`
  + Fix typo in translatable string
  + [libdnf5] Actions plugin: Add hooks `repos_configured`, `repos_loaded`, `pre/post_add_cmdline_packages`
  + Option `--providers-of` doesn't require available repos
  + Improve docs regarding the keepcache option and download command
  + needs_restarting: Fix invalid reference usage
  + download: add `--source` alias for `--srpm`
  + automatic: Fix documentation and ship config file
  + fix: quote `dnf5-command({})' in command suggestion when plugin not found
  + i18n: Unwind "Cannot {} package \"{}\"" message
  + base: Add repository to solver problem messages
  + conf: New classes for append options
  + docs: Document changes to repoinfo and repolist
  + dnf5daemon: The buildtime attribute has been added to the package_attrs option
  + bindings: Tests for using struct attributes in Python
  + bindings: Add Python attributes for structs
  + docs: Fix diff link on the dnf 5.2.0.0 changes page
  + docs: Add diff with API changes in dnf5-5.2.0.0
  + docs: Add a page about public API changes in dnf 5.2.0.0
  + system-upgrade: fix missing \n before transaction test
  + system-upgrade: comment to clarify progress bar logic
  + system-upgrade: drop [[maybe_unused]] from reboot() arg
  + system-upgrade: fix progress bars, set transaction description
  + system-upgrade: adapt to new transaction serialization format
  + system-upgrade: clean up releasever logic
  + system-upgrade: fix poweroff_after
  + copr: the dnf5 copr enable sets CoprRepoPart.enabled = true
  + Add file search result for repoquery --whatprovides
  + doc: Add enviroment variables and clarify options for loading the plugins
  + dnfdaemon: Fix Rpm interface introspection file
- Refresh patches
  + dnf5-with-static-libsolvext.patch
  + dnf5-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
  + dnf5-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  + dnf5-disable-Werror.patch
* Fri Apr 26 2024 Neal Gompa <ngompa@opensuse.org>
- Rebase to 5.2.0.0
  + Update translations from weblate
  + [DNF5] `--enable-plugin` and `--disable-plugin`: no match found message
  + [DNF5] API: Move Context::libdnf5_plugins_enablement to p_impl
  + spec: Add conflict with the former provider of plugin man pages
  + spec: Add conflict with the old provider of dnf.conf
  + [DNF5] Fix: Remove transaction_store_path from public, add getter/setter
  + [libdnf5 API] Base::get_plugins_info
  + [libdnf5 plugins] include iplugin.hpp in plugins instead of base.hpp
  + repo_sack: Treat all repos with solv_repo created as loaded (RhBug:2275530)
  + [DNF5] API: No inline methods in shared_options.hpp
  + [DNF5] API: offline::OfflineTransactionState: no inline methods, move cpp
  + [DNF5] API: Remove unused and buggy RpmTransactionItem class
  + [DNF5] Command: no inline methods
  + [DNF5] API: Context: add p_impl, move public vars to p_impl, getters
  + API: cli::session: no inline methods and public vars in opts classes
  + API: cli::session::Command: no inline methods
  + API: add p_impl to cli::session::Session
  + API: rpm::TransactionCallbacks: no inline methods
  + API: repo::RepoCallbacks: no inline methods
  + Prepare for switch of dnf5 in Rawhide
  + base: Make get_transaction_history unstable
  + Set `group` reason for packages removed by a group removal
  + [DNF5] Implement `--enable-plugin` and `--disable-plugin`
  + [libdnf5 API] Base::enable_disable_plugins
  + spec: Simplify man page files
  + Loggers: Fix: Add missing "null_loger.cpp" file
  + Loggers API: unify, explicit ctors, non-inline methods, use p_impl
  + doc: Review of DNF4 vs DNF5 CLI and configuration changes
  + Re-enable clang builds after API changes
  + Add `--store` option for storing arbitrary transaction
  + libdnf5::Goal: when adding serialized transaction accept local items
  + Goal: change `add_serialized_transaction()` to accept path to trans
  + Add group/env paths for transaction parsing/serializing
  + base::Transaction: during serialization allow specifying paths
  + base::Transaction: add `store_comps(...)` method
  + repo_sack: add stored_transaction repo and its private API
  + repo: add private API `add_xml_comps(path)`
  + Generalize logging of `read_group_solvable_from_xml(..)`
  + Add `environment_no_groups` to `GoalJobSettings`
  + libdnf5 IPlugin: Pass IPluginData instead of Base to constructor
  + libdnf5 IPlugin: Use pImpl
  + libdnf5 IPlugin: Do not use inline methods
  + dnf5 IPlugin: Do not use inline methods on API
  + libdnf5 IPlugin: Add argumets description
  + libdnf5 plugins: New hooks `pre/post_add_cmdline_packages`
  + libdnf5 plugins: New hook `repos_loaded`
  + libdnf5 plugins: New hook `repos_configured`
  + Base: notify_repos_configured and are_repos_configured methods
  + Fix: implicit conversion changes signedness, unused value
  + Disable unit tests for Copr dnf5 plugin
  + dnfdaemon: Document Polit CheckAuthorization call
  + dnfdaemon: Catch timeout during CheckAuthorization
  + Not handle compatibility.conf as configuration file
  + config: add search (se) and info (if) aliases
  + Improve documentation of repo config directories
  + Cross reference documentation
  + Document Repos and Vars Dirs
  + doc: Unify style and move "Files" section
  + Document repos configuration overrides
  + doc: Remove ":" in titles
  + Bump libdnf5/libdnf5-cli so version
  + Mark multiple strings for translation
  + Set locale for dnf5 run
  + spec: Add missing dnf-config-manager.8.gz file
  + Generate documentation for ConfigRepo Class
  + [Doc] Describe denerating repo cache path
  + dnf5daemon: Make availability case insensitive
  + dnf5: Drop unneeded severities capitalization
  + dnf5: Document --available as default for advisory cmd
  + dnf5daemon-client: Drop unneeded severities capitalization
  + advisory: filter_severity and filter_type case insensitive
  + dnfdaemon: Fix and enhance Advisory interface doc
  + Enable import data from DNF4 for systems without state dir
  + libdnf5 options: Unify constructors - pass args for storing by value
  + dnfdaemon: Missing signal registration
  + doc: config manager plugin: wrap too long lines
  + doc: document config-manager plugin
  + Packit: get version from specfile for copr_builds againts main
  + Update tests to use new `load_repos()` API
  + Use new load_repos instead of deprecated update_and_load_enabled_repos
  + Make `libdnf5::repo::Repo::load()` private
  + Deprecate: `update_and_load_enabled_repos`
  + RepoSack: add new `load_repos` method
  + Move update_and_load_repos and fix_group_missing_xml to Impl
  + Prevent loading plugins for unittests
  + Respect plugins configuration option for loading plugins
  + Add pImpl to `libdnf5::LogRouter`
  + Add pImpl to `libdnf5::MemoryBufferLogger`
  + Add pImpl to `libdnf5::OptionBinds`
  + Add pImpl to `libdnf5::OptionBinds::Item`
  + Add pImpl to `libdnf5::Config`
  + Add pImpl to `libdnf5::OptionStringList`
  + OptionStringList: remove assignment operators and move constructor
  + Add pImpl to `libdnf5::OptionBool`
  + OptionBool: remove assignment operators and move constructor
  + Add pImpl to `libdnf5::OptionNumber`
  + Add pImpl to `libdnf5::OptionPath`
  + Add pImpl to `libdnf5::OptionString`
  + libdnf5::OptionEnum: remove template, add pImpl
  + Add pImpl to `libdnf5::Option`
  + modules: Report problems with switching module streams
  + modules: Report switched module streams
  + modules: Add switching module streams as a possible transaction action
  + modules: Add replaces and replaced_by to TransactionModule
  + Add missing info updates alias, to match list command
  + Update `package_info_sections` not to use `scols_table_print_range`
  + libdnf-cli: Extract package info printing
  + ArgumentParser: use p_impl, no inline methods
  + ArgumentParser:PositionalArg: Unit tests: Support repeating of pos arg
  + ArgumentParser:PositionalArg: Support repeating of positional argument
  + Hide/Remove deprecated `libdnf5::repo::Repo` API
  + Remove deprecated members from `/include/libdnf5/logger/factory.hpp`
  + Remove deprecated unused function `create_forcearch_option()`
  + builddep: Don't escape globs, use expand_globs = false
  + builddep: Don't try to expand globs in pkg specs
  + libdnf5-cli::output: Use ifaces instead templates. Move code to .cpp files
  + Interfaces and adapters
  + module::ModuleStatus: Move to separate header file
  + comps::PackageType: Move to separate header file
  + cmp_naevr: Fix: pass by reference
  + modules: Report module solver problems
  + Accept SolverProblems for transacion resolve log
  + modules: Return problems from the module solver
  + modules: Add a method to process module solver problems
  + modules: Add a separate set of problem rules for modules
  + modules: Store the original module context also in the libsolv solvable
  + modules: Internalize modular repositories
  + Add pImpl to `libdnf5::repo::RepoCache` and `RepoCacheRemoveStatistics`
  + Add pImpl to `libdnf5::repo::RepoQuery`
  + Hide deprecated `libdnf5::base::with_config_file_path` into Impl
  + Remove deprecated `libdnf5::Base::load_config_from_file`
  + Move all `libdnf5::Base` members to pImpl
  + Add pImpl to `libdnf5::rpm::Reldep`
  + Add pImpl to `libdnf5::rpm::Changelog`
  + Add pImpl to `libdnf5::rpm::Nevra`
  + Add pImpl to `libdnf5::rpm::Checksum`
  + Add pImpl to `libdnf5::rpm::Package`
  + Adjust code to new rpm::PackageQuery::filter_* methods after the rebase
  + Add a method accepting std::string for filter_repo_id()
  + Add a method accepting std::string for filter_location()
  + Add a method accepting std::string for filter_file()
  + Add a method accepting std::string for filter_supplements()
  + Add a method accepting std::string for filter_enhances()
  + Add a method accepting std::string for filter_suggests()
  + Add a method accepting std::string for filter_recommends()
  + Add a method accepting std::string for filter_obsoletes()
  + Add a method accepting std::string for filter_conflicts()
  + Add a method accepting std::string for filter_requires()
  + Add a method accepting std::string for filter_description()
  + Add a method accepting std::string for filter_summary()
  + Add a method accepting std::string for filter_url()
  + Add a method accepting std::string for filter_sourcerpm()
  + Add a method accepting std::string for filter_nevra()
  + Add a method accepting std::string for filter_evr()
  + Add a method accepting std::string for filter_arch()
  + Add a method accepting std::string for filter_release()
  + Add a method accepting std::string for filter_version()
  + Add a method accepting std::string and int for filter_epoch()
  + Add a method accepting std::string for filter_name()
  + Add a method accepting std::string for filter_provides()
  + Extend version to four numbers (5.x.y.z)
  + Unify smallest version number name
  + cmake: rename PROJECT_VERSION_* to just VERSION_*
  + dnf5daemon: Document before_begin / after_complete signals
  + dnf5daemon: Signals to wrap rpm transaction execution
  + rpm: New callback to wrap whole rpm transaction
  + Add pImpl to `libdnf5::module::ModuleProfile`
  + Add pImpl to `libdnf5::module::ModuleDependency`
  + Add pImpl to `libdnf5::module::Nsvcap`
  + Add pImpl to `libdnf5::module::ModuleQuery`
  + Add pImpl to `libdnf5::comps::EnvironmentQuery`
  + Add pImpl to `libdnf5::comps::GroupQuery`
  + Add pImpl to `libdnf5::comps::Environment`
  + Add pImpl to `libdnf5::comps::Package`
  + Add pImpl to `libdnf5::comps::Group`
  + Remove unused `libdnf5::comps::GroupSack`
  + Remove unused `libdnf5::comps::EnvironmentSack`
  + Remove unused `libdnf5::comps::Comps`
  + Add pImpl to `libdnf5::advisory::Advisory`
  + Add pImpl to `libdnf5::advisory::AdvisoryReference`
  + Add pImpl to `libdnf5::advisory::AdvisoryCollection`
  + Add pImpl to `libdnf5::advisory::AdvisoryQuery`
  + Add pImpl to `libdnf5::rpm::RpmSignature`
  + Add pImpl to `libdnf5::transaction::Transaction`
  + Add pImpl to `libdnf5::rpm::KeyInfo`
  + Add pImpl to `libdnf5::repo::RepoSack`
  + Add pImpl to `libdnf5::base::SolverProblems`
  + Add pImpl to `libdnf5::base::LogEvent`
  + Add pImpl to `libdnf5::ConfigParser`
  + Add pImpl to `libdnf5::Vars`
  + Add pImpl to `libdnf5::transaction::TransactionHistory`
  + Add pImpl to `libdnf5::transaction::Package`
  + Add pImpl to `libdnf5::transaction::CompsGroup`
  + Add pImpl to `libdnf5::transaction::CompsEnvironment`
  + Add pImpl to `libdnf5::transaction::TransactionItem`
  + Remove several not needed imports
  + repo: add p_Impl and several needed utility methods
  + Repo: remove unused `fresh()` and `timestamp` attribute
  + Add pImpl to `ModuleItem` and remove definitions from header
  + Add pImpl to `libdnf5::base::transaction_*` classes
  + Add p_impl to libdnf5::GoalJobSettings and add getters and setters
  + Add p_impl to libdnf5::ResolveSpecSettings and add getters and setters
  + dnf5: bash completion: Prefer using "_comp_initialize" with fallback
  + dnf5: Bash completion: Switch to `_init_completion`
  + Fix `DISTRO_SYNC_ALL` (distro-sync without arguments, system upgrade)
  + Support RPMTRANS_FLAG_DEPLOOPS
  + Give inline methods hidden visibility by default
  + dnfdaemon: Make only internally used funcs static
  + dnfdaemon: Enhance Rpm.list() / Rpm.list_fd() documentation
  + doc: Add example of Rpm.list_fd usage in Python
  + dnf5daemon-client: Repoquery uses new Rpm:list_fd() API
  + dnfdaemon: New method list_fd() on Rpm interface
  + dnfdaemon: Serialize package object to JSON string
  + dnf5daemon: Handler that return data using UNIX_FD
  + dnf5daemon: Auxiliary method to write string to fd
  + dnf5daemon: Move utils functions into dnfdaemon namespace
  + dnf5daemon: get_session() method for D-Bus services
  + dnf5daemon-server: Ignore SIGPIPE
  + Vars: Add unit tests for API methods
  + Vars::unset: API method for removing variable
  + dnf5daemon-server/dbus: Install config files into /usr
  + Fix: libdnf5-cli::output::action_color: Move implementation to .cpp file
  + Fix: Do not use Variable-length arrays (VLAs) in C++ code
  + Add a hint to call base.setup() prior loading repositories
  + dnf5daemon-client: New switches for group list
  + doc: Include comps.Group interface to D-Bus API documentatin
  + dnfdaemon: Enhance comps.Group.list() method
  + dnf5daemon-client: Fix group.get_installed()
  + man: Link dnf5 pages to dnf
* Sat Apr  6 2024 Neal Gompa <ngompa@opensuse.org>
- Move dbus policy configuration from /etc to /usr
* Thu Apr  4 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.17
  + Update translations from weblate
  + dnf5daemon: Remove reposdir from allowed config overrides
  + Document system-upgrade aliases
  + Improved Bash Completion
  + Print command line hints after resolve failure
  + Docuent Advisory.list() API usage
  + Add NEVRA field to advisory packages in dnf5daemon
  + Review and fix missing commands
  + Document dnf5daemon advisory
  + Document system-upgrade
  + system-upgrade: offline status subcommand
  + Add aliases `offline-distrosync`, `offline-upgrade`
  + Add `system-upgrade --offline` option
  + Add `offline`, `system-upgrade` commands
  + Automatically set `upgrade --downloadonly` when `--destdir` is used
  + Write warnings to stderr too in config-manager plugin
  + Add repoid to generated repository name in config-manager plugin
  + Bump sdbus-cpp requirement to 0.9.0
  + Document and implement dnf5daemon Rpm interface
  + Document and implement dnf5daemon Goal interface
  + Document and implement dnf5daemon Repo interface
  + Document and implement dnf5daemon Base interface
  + Document and implement dnf5daemon Advisory interface
  + Document and implement dnf5daemon SessionManager interface
  + Add `dnf5daemon repo --enable/--disable` commands
  + automatic: Skip network availability check without remote repo
  + dnf5daemon: Rpm.list() works with commandline pkgs
* Fri Mar  8 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.14
  + Update translations from weblate
  + Make the error to resolve module metadata more descriptive
  + Switch off deltarpm support
  + Limit number of dnf5daemon simultaneously active sessions
  + Make info and list commands case insesitive
  + Allow dnf5daemon configuration overrides for root
  + Add repoquery.hpp for swig-4.2.1 support
* Mon Feb 26 2024 Neal Gompa <ngompa@opensuse.org>
- Fix dependency on libcurl in dnf5-automatic
* Fri Feb 23 2024 Neal Gompa <ngompa@opensuse.org>
- Move libdnf5 plugin directory ownership to libdnf5 package
* Fri Feb 23 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.13
  + Change location of automatic.conf
  + Limit message log to one on dnf5 start
  + Implement waiting for network for dnf5 automatic
  + Write dnf5 commandline to the log
  + Implement dnf5-automatic: Tool for managing automatic upgrades
  + Parametrize output stream in transaction table
  + Add `download --srpm` option
  + Add missing dbus signal registations
  + Add new versionlock bindings
  + Implement `dnf5 versionlock` command
* Sun Feb 18 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.12
  + Update translations from weblate
  + Drop dnf obsoletion temporarily
  + Use regex for tmt plan names
  + Add tmt tests identifiers
  + PackageQuery: Add `filter_{latest,earliest}_evr_ignore_arch`
  + Suggest to use dnf5 command to install dnf5 plugins
  + Added arch option to the download command
  + CI: Upgrade action/checkout to a version with Node.js 20
  + Document explicit nevra remove commands and aliases dropped
  + build: Include <unistd.h> for isatty()
  + Change user info display on history command to include display name and username
  + Revert "Use focusbest: prefer latest deps versions over smaller transactions"
  + Fix a warning when building docs.
  + modules: Add a test for enabling default modules
  + modules: Add a new module stream to test data
  + modules: Respect defaults when enabling multiple streams of a module
  + modules: Fix TransactionItemType for not found modules
  + Build: Require GCC 10.1 for std::in_range<>()
  + Add --urlprotocol option to download command
  + dnfdaemon: Explicitly specify allowed config overrides
  + Disable dnf and dnf5daemon tests
  + needs-restarting: get systemd boot time from UnitsLoadStartTimestamp
  + doc: Add --destdir option to upgrade command manual
  + Move number placeholder to postposition in copr_repo.cpp
  + Added url option
  + Load protected packages from installroot
  + Make protected_packages an append options
  + doc: Create a man page for Aliases
  + I18N: Annotate literals in advisory command
  + Extend filter_release and filter_version tests
  + package_query: Fix filter_version with non EQ comparator
  + Fix clang format
  + Fix code for string deduplication
  + Use placeholders to deduplicate strings
  + Add __hash__(), __str__(), and __repr__() for Package
  + Add __hash__() for Reldep Python binding
  + Add __repr__() to python bindings of Reldep
  + Define tp_str slot for Reldep Class
  + group: Fix using allowerasing option
  + Fix misspellings
  + I18N: Remove duplicate empty message IDs from catalogs
  + I18N: Do not mark empty strings for a translation
* Thu Jan 11 2024 Neal Gompa <ngompa@opensuse.org>
- Refresh patches to fix the build
  + Remove patch: dnf5-5.1.3-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  + Remove patch: dnf5-5.1.3-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
  + Remove patch: dnf5-5.1.4-with-static-libsolvext.patch
  + Add Patch: dnf5-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  + Add Patch: dnf5-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
  + Add Patch: dnf5-with-static-libsolvext.patch
* Thu Jan 11 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.11
  + Update translations from weblate
  + Fix `--skip-unavailable` documentation
  + Make `cachedir`, `system_cachedir` relative to `installroot`
  + Workaround for swig-4.2.0 missing fragment dependency
  + Add `repoquery --recursive` option
  + Add `repoquery --providers-of=PACKAGE_ATTRIBUTE` option
  + Update documentation of repoquery
  + Update documentation for remove command behavior
  + Limit search pattern for remove command to NEVRAs and files
  + Disable zchunk on RHEL
  + Add dnf5.conf man page
  + Add RPM package Group attribute to dnf5daemon-server
  + Document changes related to caching
  + Document caching man page
  + Document Global Option `--help-cmd` dropped
  + log_event: Correct message for HINT_ICASE
- Drop patch to support RPM Group tag in dnf5daemon as it's part of this release
  + Patch: 0001-dnf5daemon-server-Add-RPM-package-Group-attribute.patch
* Wed Jan  3 2024 Neal Gompa <ngompa@opensuse.org>
- Update to 5.1.10
  + Document dnf5 plugins
  + Document How-to write libdnf5 plugin tutorial
  + Document How-to write dnf5 plugin tutorial
  + Document Templates for libdnf5 plugin
  + Document Templates for dnf5 plugin
  + Sort the module info table
  + `module info` print hint for active modules
  + `module info` print "[a]" for active modules
  + Ensure write permission before importing packages
  + Change module dependency string to be the same as in dnf4
  + `module info`: improve summary and description
  + Escape glob characters in pkg specs for `builddep`
  + Add `mc` alias for `makecache`
  + Implement `logdir`, `log_size` and `log_rotate` config options
  + remove redundant "all" in command `check`
  + Improve bash completion
  + Fix progress bars miss newlines on non-interactive output
- Add patch to support RPM Group tag in dnf5daemon
  + Patch: 0001-dnf5daemon-server-Add-RPM-package-Group-attribute.patch
* Wed Dec 27 2023 Neal Gompa <ngompa@opensuse.org>
- Add missing directories to libdnf5 subpackage
- Unify formatting of build conditionals
* Wed Dec 27 2023 Neal Gompa <ngompa@opensuse.org>
- Add missing file list entry for as_yum conditional
* Thu Dec 21 2023 Neal Gompa <ngompa@opensuse.org>
- Initial packaging based on Fedora package
- Add initial SUSE specific patches to fix the build
  + Patch: dnf5-disable-Werror.patch
  + Patch: dnf5-5.1.3-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  + Patch: dnf5-5.1.3-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
  + Patch: dnf5-5.1.4-with-static-libsolvext.patch
